@@ -163,3 +163,17 @@ void service_cisco(char *ip, int sp, unsigned char options, char *miscptr, FILE
     run = next_run;
   }
 }
+
+int service_cisco_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
