@@ -124,6 +124,7 @@ char *strrep(char *string, char *oldpiece, char *newpiece) {
 /*
 int analyze_server_response(int socket)
 return 0 or 1 when the cond regex is matched
+return -1 if no response from server
 */
 int analyze_server_response(int s) {
   int runs = 0;
@@ -195,8 +196,7 @@ int analyze_server_response(int s) {
               ptr2 += 2;
               strncat(tmpcookie, ptr2, sizeof(tmpcookie) - strlen(tmpcookie) - 1);
             }
-            if (debug)
-              printf("[DEBUG] removing cookie %s in jar\n before: %s\n after:  %s\n", tmpname, cookie, tmpcookie);
+            if (debug) printf("[DEBUG] removing cookie %s in jar\n before: %s\n after:  %s\n", tmpname, cookie, tmpcookie);
             strcpy(cookie, tmpcookie);
           }
         }
@@ -222,6 +222,10 @@ int analyze_server_response(int s) {
 //    else printf("DEBUG: STRING %s NOT FOUND:\n%s\n", cond, buf);
     free(buf);
   }
+  if (runs == 0) {
+    if (debug) hydra_report(stderr, "DEBUG: no response from server\n");
+    return -1;
+  }
   return 0;
 }
 
@@ -418,8 +422,7 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
           }
         } else
           strncpy(str3, redirected_url_buff, sizeof(str3));
-       if (debug)
-         hydra_report(stderr, "[DEBUG] host=%s redirect=%s origin=%s\n", str2, str3,url);
+       if (debug) hydra_report(stderr, "[DEBUG] host=%s redirect=%s origin=%s\n", str2, str3,url);
       }
       if (str3[0] != '/') {
         j = strlen(str3);
@@ -460,7 +463,7 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
   }
 
   //if the last status is still 3xx, set it as a false
-  if (found == success_cond && redirected_flag == 0 && redirected_cpt >= 0) {
+  if (found != -1 && found == success_cond && redirected_flag == 0 && redirected_cpt >= 0) {
     hydra_report_found_host(port, ip, "www-form", fp);
     hydra_completed_pair_found();
   } else {
@@ -619,3 +622,17 @@ void service_http_get_form(char *ip, int sp, unsigned char options, char *miscpt
 void service_http_post_form(char *ip, int sp, unsigned char options, char *miscptr, FILE * fp, int port) {
   service_http_form(ip, sp, options, miscptr, fp, port, "POST");
 }
+
+int service_http_form_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
