@@ -1,7 +1,6 @@
 #include "hydra-mod.h"
 #include "sasl.h"
 
-extern int module_auth_type;
 extern char *HYDRA_EXIT;
 char *buf;
 int counter;
@@ -551,3 +550,17 @@ void service_imap(char *ip, int sp, unsigned char options, char *miscptr, FILE *
     run = next_run;
   }
 }
+
+int service_imap_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
