@@ -1,7 +1,6 @@
 #include "hydra-mod.h"
 #include "sasl.h"
 
-extern int module_auth_type;
 extern char *HYDRA_EXIT;
 
 unsigned char *buf;
@@ -440,3 +439,17 @@ void service_ldap3_cram_md5(char *ip, int sp, unsigned char options, char *miscp
 void service_ldap3_digest_md5(char *ip, int sp, unsigned char options, char *miscptr, FILE * fp, int port) {
   service_ldap(ip, sp, options, miscptr, fp, port, 3, AUTH_DIGESTMD5);
 }
+
+int service_ldap_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
