@@ -41,6 +41,8 @@ int __fck = 0;
 int ssl_first = 1;
 int __first_connect = 1;
 char ipstring[64];
+unsigned int colored_output = 1;
+
 #ifdef LIBOPENSSL
 SSL *ssl = NULL;
 SSL_CTX *sslContext = NULL;
@@ -424,7 +426,7 @@ int internal__hydra_connect(char *host, int port, int protocol, int type) {
 #ifdef LIBOPENSSL
 RSA *ssl_temp_rsa_cb(SSL * ssl, int export, int keylength) {
   if (rsa == NULL)
-    rsa = RSA_generate_key(512, RSA_F4, NULL, NULL);
+    rsa = RSA_generate_key(1024, RSA_F4, NULL, NULL);
   return rsa;
 }
 
@@ -434,7 +436,8 @@ int internal__hydra_connect_to_ssl(int socket) {
 
   if (ssl_first) {
     SSL_load_error_strings();
-    SSL_library_init();
+//    SSL_add_ssl_algoritms();
+    SSL_library_init();		// ?
     ssl_first = 0;
   }
 
@@ -635,16 +638,35 @@ void hydra_report_debug(FILE * st, char *format, ...) {
 
 void hydra_report_found(int port, char *svc, FILE * fp) {
   if (!strcmp(svc, "rsh"))
-    fprintf(fp, "[%d][%s] login: %s\n", port, svc, hydra_get_next_login());
+    if (colored_output)
+      fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] login: \e[32m%s\e[0m\n", port, svc, hydra_get_next_login());
+    else
+      fprintf(fp, "[%d][%s] login: %s\n", port, svc, hydra_get_next_login());
   else
-    fprintf(fp, "[%d][%s] login: %s   password: %s\n", port, svc, hydra_get_next_login(), hydra_get_next_password());
+    if (colored_output)
+      fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] login: \e[32m%s\e[0m   password: \e[32m%s\e[0m\n", port, svc, hydra_get_next_login(), hydra_get_next_password());
+    else
+      fprintf(fp, "[%d][%s] login: %s   password: %s\n", port, svc, hydra_get_next_login(), hydra_get_next_password());
+
+  if (stdout != fp) {
+    if (!strcmp(svc, "rsh"))
+      printf("[%d][%s] login: %s\n", port, svc, hydra_get_next_login());
+    else
+      printf("[%d][%s] login: %s   password: %s\n", port, svc, hydra_get_next_login(), hydra_get_next_password());
+  }
+
   fflush(fp);
 }
 
 /* needed for irc module to display the general server password */
 void hydra_report_pass_found(int port, char *ip, char *svc, FILE * fp) {
   strcpy(ipaddr_str, hydra_address2string(ip));
-  printf("[%d][%s] host: %s   password: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
+  if (colored_output)
+   fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] host: \e[32m%s\e[0m   password: \e[32m%s\e[0m\n", port, svc, ipaddr_str, hydra_get_next_password());
+  else
+   fprintf(fp, "[%d][%s] host: %s   password: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
+  if (stdout != fp)
+    printf("[%d][%s] host: %s   password: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
   fflush(fp);
 }
 
@@ -655,13 +677,25 @@ void hydra_report_found_host(int port, char *ip, char *svc, FILE * fp) {
   if (!strcmp(svc, "smtp-enum"))
     keyw = "domain";
   if (!strcmp(svc, "rsh") || !strcmp(svc, "oracle-sid"))
-    fprintf(fp, "[%d][%s] host: %s   login: %s\n", port, svc, ipaddr_str, hydra_get_next_login());
+    if (colored_output)
+      fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] host: \e[32m%s\e[0m   login: \e[32m%s\e[0m\n", port, svc, ipaddr_str, hydra_get_next_login());
+    else
+      fprintf(fp, "[%d][%s] host: %s   login: %s\n", port, svc, ipaddr_str, hydra_get_next_login());
   else if (!strcmp(svc, "snmp3"))
-    fprintf(fp, "[%d][%s] host: %s   login: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
+    if (colored_output)
+      fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] host: \e[32m%s\e[0m   login: \e[32m%s\e[0m\n", port, svc, ipaddr_str, hydra_get_next_password());
+    else    
+      fprintf(fp, "[%d][%s] host: %s   login: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
   else if (!strcmp(svc, "cisco-enable") || !strcmp(svc, "cisco"))
-    fprintf(fp, "[%d][%s] host: %s   password: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
+    if (colored_output)
+      fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] host: \e[32m%s\e[0m   password: \e[32m%s\e[0m\n", port, svc, ipaddr_str, hydra_get_next_password());
+     else
+      fprintf(fp, "[%d][%s] host: %s   password: %s\n", port, svc, ipaddr_str, hydra_get_next_password());
   else
-    fprintf(fp, "[%d][%s] host: %s   login: %s   %s: %s\n", port, svc, ipaddr_str, hydra_get_next_login(), keyw, hydra_get_next_password());
+    if (colored_output)
+      fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] host: \e[32m%s\e[0m   login: \e[32m%s\e[0m   %s: \e[32m%s\e[0m\n", port, svc, ipaddr_str, hydra_get_next_login(), keyw, hydra_get_next_password());
+    else
+      fprintf(fp, "[%d][%s] host: %s   login: %s   %s: %s\n", port, svc, ipaddr_str, hydra_get_next_login(), keyw, hydra_get_next_password());
   if (stdout != fp) {
     if (!strcmp(svc, "rsh") || !strcmp(svc, "oracle-sid"))
       printf("[%d][%s] host: %s   login: %s\n", port, svc, ipaddr_str, hydra_get_next_login());
@@ -678,7 +712,10 @@ void hydra_report_found_host(int port, char *ip, char *svc, FILE * fp) {
 
 void hydra_report_found_host_msg(int port, char *ip, char *svc, FILE * fp, char *msg) {
   strcpy(ipaddr_str, hydra_address2string(ip));
-  fprintf(fp, "[%d][%s] host: %s   login: %s   password: %s  [%s]\n", port, svc, ipaddr_str, hydra_get_next_login(), hydra_get_next_password(), msg);
+  if (colored_output)
+    fprintf(fp, "[\e[31m%d\e[0m][\e[31m%s\e[0m] host: \e[32m%s\e[0m   login: \e[32m%s\e[0m   password: \e[32m%s\e[0m  [%s]\n", port, svc, ipaddr_str, hydra_get_next_login(), hydra_get_next_password(), msg);
+  else
+    fprintf(fp, "[%d][%s] host: %s   login: %s   password: %s  [%s]\n", port, svc, ipaddr_str, hydra_get_next_login(), hydra_get_next_password(), msg);
   if (stdout != fp)
     printf("[%d][%s] host: %s   login: %s   password: %s\n", port, svc, ipaddr_str, hydra_get_next_login(), hydra_get_next_password());
   fflush(fp);
@@ -695,7 +732,7 @@ int hydra_connect_to_ssl(int socket) {
 int hydra_connect_ssl(char *host, int port) {
   if (__first_connect != 0)
     __first_connect = 0;
-  else if (conwait > 0)
+  else
     sleep(conwait);
 #ifdef LIBOPENSSL
   return (internal__hydra_connect_ssl(host, port, SOCK_STREAM, 6));
@@ -707,7 +744,7 @@ int hydra_connect_ssl(char *host, int port) {
 int hydra_connect_tcp(char *host, int port) {
   if (__first_connect != 0)
     __first_connect = 0;
-  else if (conwait > 0)
+  else
     sleep(conwait);
   return (internal__hydra_connect(host, port, SOCK_STREAM, 6));
 }
@@ -715,7 +752,7 @@ int hydra_connect_tcp(char *host, int port) {
 int hydra_connect_udp(char *host, int port) {
   if (__first_connect != 0)
     __first_connect = 0;
-  else if (conwait > 0)
+  else
     sleep(conwait);
   return (internal__hydra_connect(host, port, SOCK_DGRAM, 17));
 }
@@ -802,7 +839,7 @@ char *hydra_receive_line(int socket) {
   }
   memset(buff, 0, sizeof(buf));
   if (debug)
-    printf("[DEBUG] hydra_receive_line: waittime: %d, socket: %d, pid: %d\n", waittime, socket, getpid());
+    printf("[DEBUG] hydra_receive_line: waittime: %d, conwait: %d, socket: %d, pid: %d\n", waittime, conwait, socket, getpid());
 
   if ((i = hydra_data_ready_timed(socket, (long) waittime, 0)) > 0) {
     if ((got = internal__hydra_recv(socket, buff, sizeof(buf) - 1)) < 0) {
@@ -811,7 +848,7 @@ char *hydra_receive_line(int socket) {
     }
   } else {
     if (debug)
-      printf("[DEBUG] hydra_data_ready_timed: %d, waittime: %d, socket: %d\n", i, waittime, socket);
+      printf("[DEBUG] hydra_data_ready_timed: %d, waittime: %d, conwait: %d, socket: %d\n", i, waittime, conwait, socket);
     i = 0;
   }
 
