@@ -405,3 +405,17 @@ char *hydra_scramble(char *to, const char *message, const char *password) {
   return to;
 }
 #endif
+
+int service_mysql_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
