@@ -10,7 +10,6 @@ RFC 4643: Network News Transfer Protocol (NNTP) Extension for Authentication
 
 */
 
-extern int module_auth_type;
 int nntp_auth_mechanism = AUTH_CLEAR;
 
 extern char *HYDRA_EXIT;
@@ -454,3 +453,17 @@ SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
     run = next_run;
   }
 }
+
+int service_nntp_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
