@@ -1853,8 +1853,11 @@ static void process_memblt(STREAM s, MEMBLT_ORDER * os, uint32 present, BOOL del
     in_uint16_le(s, os->cache_idx);
 
   DEBUG(("MEMBLT(op=0x%x,x=%d,y=%d,cx=%d,cy=%d,id=%d,idx=%d)\n", os->opcode, os->x, os->y, os->cx, os->cy, os->cache_id, os->cache_idx));
+  //MEMBLT(op=0xcc,x=640,y=128,cx=64,cy=64,id=2,idx=117) => win8 failed
 
-  if (os->opcode == 0xcc && os->x == 740 && os->y == 448 && os->cx == 60 && os->cy == 56 && os->cache_id == 2) {
+  if ((os->opcode == 0xcc && os->x == 740 && os->y == 448 && os->cx == 60 && os->cy == 56 && os->cache_id == 2)||
+      (os->opcode == 0xcc && os->x == 640 && os->y == 128 && os->cx == 64 && os->cy == 64 && os->cache_id == 2 && os->cache_idx > 100))
+  {
     if (debug)
       hydra_report(stderr, "[DEBUG] Login failed from process_memblt\n");
     login_result = LOGIN_FAIL;
@@ -3190,3 +3193,17 @@ static BOOL process_data_pdu(STREAM s, uint32 * ext_disc_reason) {
   return False;
 }
 #endif
+
+int service_rdp_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
