@@ -254,11 +254,13 @@ int start_snmp(int s, char *ip, int port, unsigned char options, char *miscptr,
 
     if (hashtype > 0) {
       off = 12;
+#ifdef LIBOPENSSL
       if (hashtype == 1) {
         password_to_key_md5(pass, strlen(pass), snmpv3info + 6, snmpv3info[5], key);
       } else {
         password_to_key_sha(pass, strlen(pass), snmpv3info + 6, snmpv3info[5], key);
       }
+#endif
       if (enctype > 0) {
         off += 8;
         buffer[20 + off2] = 7;
@@ -309,6 +311,9 @@ int start_snmp(int s, char *ip, int port, unsigned char options, char *miscptr,
     } else {
       buffer[i] = 4;
       buffer[i + 1] = 0x30;
+
+#ifdef LIBOPENSSL
+
 /*
 //PrivDES::encrypt(const unsigned char *key,  
 //                 const unsigned int   /*key_len*///,  
@@ -332,6 +337,9 @@ int start_snmp(int s, char *ip, int port, unsigned char options, char *miscptr,
       initVect[i] ^= privacy_params[i];  
     des_key_sched((C_Block*)key, symcbc);
     des_ncbc_encrypt(snmpv3_get2 + 2, buf, sizeof(snmpv3_get2) - 2, symcbc, (C_Block*)(initVect), DES_ENCRYPT);
+
+#endif
+
 /*  for (i = 0; i <= sizeof(snmpv3_get2) - 8; i += 8) {  
     des_ncbc_encrypt(snmpv3_get2 + i, buf + i, 8, (C_Block*)(initVect), DES_ENCRYPT);
   }  
@@ -557,3 +565,17 @@ void service_snmp(char *ip, int sp, unsigned char options, char *miscptr, FILE *
     run = next_run;
   }
 }
+
+int service_snmp_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
